summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgameerror.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/kgameerror.h')
-rw-r--r--libkdegames/kgame/kgameerror.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libkdegames/kgame/kgameerror.h b/libkdegames/kgame/kgameerror.h
index 2916e891..071737cc 100644
--- a/libkdegames/kgame/kgameerror.h
+++ b/libkdegames/kgame/kgameerror.h
@@ -23,7 +23,7 @@
#ifndef __KGAMEERROR_H_
#define __KGAMEERROR_H_
-#include <qstring.h>
+#include <tqstring.h>
class KGameError
@@ -40,19 +40,19 @@ public:
/**
* Generate an error message with Erorr Code = ErrCookie
**/
- static QByteArray errCookie(int localCookie, int remoteCookie);
- static QByteArray errVersion(int remoteVersion);
+ static TQByteArray errCookie(int localCookie, int remoteCookie);
+ static TQByteArray errVersion(int remoteVersion);
/**
* Create an erorr text using a QDataStream (QByteArray) which was
* created using @ref KGameError. This is the opposite function to all
* the errXYZ() function (e.g. @ref errVersion).
* You want to use this to generate the message that shall be
* displayed to the user.
* @return an error message
**/
- static QString errorText(int errorCode, QDataStream& message);
- static QString errorText(int errorCode, const QByteArray& message);
+ static TQString errorText(int errorCode, TQDataStream& message);
+ static TQString errorText(int errorCode, const TQByteArray& message);
};
@@ -40,19 +40,19 @@ public:
/**
- * Create an erorr text using a QDataStream (QByteArray) which was
+ * Create an erorr text using a TQDataStream (TQByteArray) which was
* created using @ref KGameError. This is the opposite function to all
* the errXYZ() function (e.g. @ref errVersion).